## Introduction

This is a helper tool for fetch content from Flow Framework / Neos CMS installation on a remote server to your local
computer running with docker.

## Dependency

This is requires that your Flow Framework / Neos CMS installation is configured to run with `dockerflow` package
(see https://github.com/Sebobo/Shel.DockerFlow) and all containers are started before executing the sync.

## Installation

Add the `syncontent` package into your `composer.json` file and update `composer.lock`. It is recommended to add in the
`require-dev` section of your composer.

```
"visay/syncontent": "dev-master"
```

## Usage

In the root directory of your project, execute:

```bash
bin/syncontent --remote-user=demo-014-007
```

- Replace the user `demo-014-007` with the one you want to get content from
- You need to make sure that you have auto login with public key to `demo-014-007@YOUR_SERVER_HOSTNAME_OR_IP`.
The default host server is `10.10.10.27`, which is the internal web server
- You can define different server host with `--remote-host=YOUR_SERVER_HOSTNAME_OR_IP` argument
- Only `latest` or `demo` is supported at the moment. We don't recommend you to have autologin access to the live site
- You can only run the command from the root directory of your project
- The document root on the server will have to be at `/home/demo-014-007/public_html`
- If you have a different document root path, you can overwrite the default with `--remote-path` argument

So the full overwriting way would be:

```bash
bin/syncontent --remote-user=demo-014-007 --remote-host=10.10.10.37 --remote-path=/home/user/neosbox
```

Or short form of the arguments:

```bash
bin/syncontent -u=demo-014-007 -h=10.10.10.37 -p=/home/user/neosbox
```

### Available arguments

- `-u` | `--remote-user` : Set the login user to the remote server (__Required__)
- `-h` | `--remote-host` : Set the hostname or IP address of the remote server (__Default__: `10.10.10.27`)
- `-p` | `--remote-path` : Set path to the document root on the remote server (__Default__: `/home/<remote-user>/public_html`)

### Customization

If you are lazy typing the user again and again, you can define it permanently by creating a file in
`Packages/Libraries/visay/syncontent/config/master` with the same name as the `--remote-user` value.

```
Packages
└── Libraries
	└── visay
		└── syncontent
			├── ansible
			├── bin
			├── composer.json
			├── config
			│   └── master
			│       └── demo-014-007
			└── README.md
```

You can also overwrite the default value of `--remote-host` and `--remote-path` by setting it in the created master file.

```Packages/Libraries/visay/syncontent/config/master/demo-014-007
--remote-host=10.10.10.37
--remote-path=/home/user/neosbox
```

With this file and its content, you can now execute the content sync with just:

```bash
bin/syncontent
```

And the script will automatically take `demo-014-007` as the content master, `10.10.10.37` as server host and
`/home/user/neosbox` as remote path.

- You can also combine that some settings are in config file and some are passed as argument
- If the same config are set in the config and pass as argument, the argument value will take effect
- There should be only one master at a time. That means you should not have more than more file in the `config/master`
directory. In case there are more than one file exists, the script will take first file only to process.
- In most case, the default host and path work fine for internal Web Essentials project development
and you just need to define the `--remote-user`

## Author

Visay Keo <visay@web-essentials.asia>

If you have any feedback, comments and/or questions, feel free to contact with email address above. And of course,
a merge request is always welcomed.
